/* score.c generated by valac 0.34.0.65-f52b, the Vala compiler
 * generated from score.vala, do not modify */

/* -*- Mode: vala; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * Copyright © 2014 Nikhar Agrawal
 *
 * This file is part of libgnome-games-support.
 *
 * libgnome-games-support is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * libgnome-games-support is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libgnome-games-support.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>


#define GAMES_SCORES_TYPE_SCORE (games_scores_score_get_type ())
#define GAMES_SCORES_SCORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_SCORES_TYPE_SCORE, GamesScoresScore))
#define GAMES_SCORES_SCORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_SCORES_TYPE_SCORE, GamesScoresScoreClass))
#define GAMES_SCORES_IS_SCORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_SCORES_TYPE_SCORE))
#define GAMES_SCORES_IS_SCORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_SCORES_TYPE_SCORE))
#define GAMES_SCORES_SCORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_SCORES_TYPE_SCORE, GamesScoresScoreClass))

typedef struct _GamesScoresScore GamesScoresScore;
typedef struct _GamesScoresScoreClass GamesScoresScoreClass;
typedef struct _GamesScoresScorePrivate GamesScoresScorePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

struct _GamesScoresScore {
	GObject parent_instance;
	GamesScoresScorePrivate * priv;
};

struct _GamesScoresScoreClass {
	GObjectClass parent_class;
};

struct _GamesScoresScorePrivate {
	glong _score;
	gchar* _user;
	gint64 _time;
};


static gpointer games_scores_score_parent_class = NULL;

GType games_scores_score_get_type (void) G_GNUC_CONST;
#define GAMES_SCORES_SCORE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GAMES_SCORES_TYPE_SCORE, GamesScoresScorePrivate))
enum  {
	GAMES_SCORES_SCORE_DUMMY_PROPERTY,
	GAMES_SCORES_SCORE_SCORE,
	GAMES_SCORES_SCORE_USER,
	GAMES_SCORES_SCORE_TIME
};
GamesScoresScore* games_scores_score_new (glong score, gint64 time, const gchar* user);
GamesScoresScore* games_scores_score_construct (GType object_type, glong score, gint64 time, const gchar* user);
void games_scores_score_set_score (GamesScoresScore* self, glong value);
void games_scores_score_set_time (GamesScoresScore* self, gint64 value);
void games_scores_score_set_user (GamesScoresScore* self, const gchar* value);
gboolean games_scores_score_equals (GamesScoresScore* a, GamesScoresScore* b);
glong games_scores_score_get_score (GamesScoresScore* self);
gint64 games_scores_score_get_time (GamesScoresScore* self);
const gchar* games_scores_score_get_user (GamesScoresScore* self);
static void games_scores_score_finalize (GObject* obj);
static void _vala_games_scores_score_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_games_scores_score_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GamesScoresScore* games_scores_score_construct (GType object_type, glong score, gint64 time, const gchar* user) {
	GamesScoresScore * self = NULL;
	glong _tmp0_ = 0L;
	gint64 _tmp1_ = 0LL;
	gint64 _tmp2_ = 0LL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	self = (GamesScoresScore*) g_object_new (object_type, NULL);
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp0_ = score;
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	games_scores_score_set_score (self, _tmp0_);
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp2_ = time;
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	if (_tmp2_ == ((gint64) 0)) {
#line 101 "score.c"
		GDateTime* _tmp3_ = NULL;
		GDateTime* _tmp4_ = NULL;
		gint64 _tmp5_ = 0LL;
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp3_ = g_date_time_new_now_local ();
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp4_ = _tmp3_;
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp5_ = g_date_time_to_unix (_tmp4_);
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp1_ = _tmp5_;
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_g_date_time_unref0 (_tmp4_);
#line 115 "score.c"
	} else {
		gint64 _tmp6_ = 0LL;
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp6_ = time;
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp1_ = _tmp6_;
#line 122 "score.c"
	}
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	games_scores_score_set_time (self, _tmp1_);
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp8_ = user;
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	if (_tmp8_ == NULL) {
#line 130 "score.c"
		const gchar* _tmp9_ = NULL;
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp9_ = g_get_real_name ();
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp7_ = _tmp9_;
#line 136 "score.c"
	} else {
		const gchar* _tmp10_ = NULL;
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp10_ = user;
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp7_ = _tmp10_;
#line 143 "score.c"
	}
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	games_scores_score_set_user (self, _tmp7_);
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	return self;
#line 149 "score.c"
}


GamesScoresScore* games_scores_score_new (glong score, gint64 time, const gchar* user) {
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	return games_scores_score_construct (GAMES_SCORES_TYPE_SCORE, score, time, user);
#line 156 "score.c"
}


gboolean games_scores_score_equals (GamesScoresScore* a, GamesScoresScore* b) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GamesScoresScore* _tmp2_ = NULL;
	glong _tmp3_ = 0L;
	GamesScoresScore* _tmp4_ = NULL;
	glong _tmp5_ = 0L;
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_return_val_if_fail (a != NULL, FALSE);
#line 41 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_return_val_if_fail (b != NULL, FALSE);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp2_ = a;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp3_ = _tmp2_->priv->_score;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp4_ = b;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp5_ = _tmp4_->priv->_score;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	if (_tmp3_ == _tmp5_) {
#line 182 "score.c"
		GamesScoresScore* _tmp6_ = NULL;
		gint64 _tmp7_ = 0LL;
		GamesScoresScore* _tmp8_ = NULL;
		gint64 _tmp9_ = 0LL;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp6_ = a;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp7_ = _tmp6_->priv->_time;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp8_ = b;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp9_ = _tmp8_->priv->_time;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp1_ = _tmp7_ == _tmp9_;
#line 197 "score.c"
	} else {
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp1_ = FALSE;
#line 201 "score.c"
	}
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	if (_tmp1_) {
#line 205 "score.c"
		GamesScoresScore* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		GamesScoresScore* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp10_ = a;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp11_ = _tmp10_->priv->_user;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp12_ = b;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp13_ = _tmp12_->priv->_user;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp0_ = g_strcmp0 (_tmp11_, _tmp13_) == 0;
#line 220 "score.c"
	} else {
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		_tmp0_ = FALSE;
#line 224 "score.c"
	}
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	result = _tmp0_;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	return result;
#line 230 "score.c"
}


glong games_scores_score_get_score (GamesScoresScore* self) {
	glong result;
	glong _tmp0_ = 0L;
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_return_val_if_fail (self != NULL, 0L);
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp0_ = self->priv->_score;
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	result = _tmp0_;
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	return result;
#line 245 "score.c"
}


void games_scores_score_set_score (GamesScoresScore* self, glong value) {
	glong _tmp0_ = 0L;
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp0_ = value;
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	self->priv->_score = _tmp0_;
#line 26 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_object_notify ((GObject *) self, "score");
#line 259 "score.c"
}


const gchar* games_scores_score_get_user (GamesScoresScore* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp0_ = self->priv->_user;
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	result = _tmp0_;
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	return result;
#line 274 "score.c"
}


void games_scores_score_set_user (GamesScoresScore* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_return_if_fail (self != NULL);
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp0_ = value;
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_g_free0 (self->priv->_user);
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	self->priv->_user = _tmp1_;
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_object_notify ((GObject *) self, "user");
#line 293 "score.c"
}


gint64 games_scores_score_get_time (GamesScoresScore* self) {
	gint64 result;
	gint64 _tmp0_ = 0LL;
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_return_val_if_fail (self != NULL, 0LL);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp0_ = self->priv->_time;
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	result = _tmp0_;
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	return result;
#line 308 "score.c"
}


void games_scores_score_set_time (GamesScoresScore* self, gint64 value) {
	gint64 _tmp0_ = 0LL;
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_return_if_fail (self != NULL);
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_tmp0_ = value;
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	self->priv->_time = _tmp0_;
#line 32 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_object_notify ((GObject *) self, "time");
#line 322 "score.c"
}


static void games_scores_score_class_init (GamesScoresScoreClass * klass) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	games_scores_score_parent_class = g_type_class_peek_parent (klass);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_type_class_add_private (klass, sizeof (GamesScoresScorePrivate));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_games_scores_score_get_property;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_games_scores_score_set_property;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	G_OBJECT_CLASS (klass)->finalize = games_scores_score_finalize;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GAMES_SCORES_SCORE_SCORE, g_param_spec_long ("score", "score", "score", G_MINLONG, G_MAXLONG, 0L, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GAMES_SCORES_SCORE_USER, g_param_spec_string ("user", "user", "user", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GAMES_SCORES_SCORE_TIME, g_param_spec_int64 ("time", "time", "time", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "score.c"
}


static void games_scores_score_instance_init (GamesScoresScore * self) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	self->priv = GAMES_SCORES_SCORE_GET_PRIVATE (self);
#line 350 "score.c"
}


static void games_scores_score_finalize (GObject* obj) {
	GamesScoresScore * self;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GAMES_SCORES_TYPE_SCORE, GamesScoresScore);
#line 27 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	_g_free0 (self->priv->_user);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	G_OBJECT_CLASS (games_scores_score_parent_class)->finalize (obj);
#line 362 "score.c"
}


GType games_scores_score_get_type (void) {
	static volatile gsize games_scores_score_type_id__volatile = 0;
	if (g_once_init_enter (&games_scores_score_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesScoresScoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_scores_score_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesScoresScore), 0, (GInstanceInitFunc) games_scores_score_instance_init, NULL };
		GType games_scores_score_type_id;
		games_scores_score_type_id = g_type_register_static (G_TYPE_OBJECT, "GamesScoresScore", &g_define_type_info, 0);
		g_once_init_leave (&games_scores_score_type_id__volatile, games_scores_score_type_id);
	}
	return games_scores_score_type_id__volatile;
}


static void _vala_games_scores_score_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GamesScoresScore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GAMES_SCORES_TYPE_SCORE, GamesScoresScore);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	switch (property_id) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		case GAMES_SCORES_SCORE_SCORE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		g_value_set_long (value, games_scores_score_get_score (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		case GAMES_SCORES_SCORE_USER:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		g_value_set_string (value, games_scores_score_get_user (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		case GAMES_SCORES_SCORE_TIME:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		g_value_set_int64 (value, games_scores_score_get_time (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		break;
#line 401 "score.c"
		default:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		break;
#line 407 "score.c"
	}
}


static void _vala_games_scores_score_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GamesScoresScore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GAMES_SCORES_TYPE_SCORE, GamesScoresScore);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
	switch (property_id) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		case GAMES_SCORES_SCORE_SCORE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		games_scores_score_set_score (self, g_value_get_long (value));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		case GAMES_SCORES_SCORE_USER:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		games_scores_score_set_user (self, g_value_get_string (value));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		case GAMES_SCORES_SCORE_TIME:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		games_scores_score_set_time (self, g_value_get_int64 (value));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		break;
#line 435 "score.c"
		default:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/score.vala"
		break;
#line 441 "score.c"
	}
}



